@@ -14,7 +14,7 @@ Usage::
 """
 from typing import Any, Dict, List, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .type_defs import GetPersonalizedRankingResponseTypeDef, GetRecommendationsResponseTypeDef
 
@@ -35,20 +35,25 @@ class Exceptions:
     ResourceNotFoundException: Type[BotocoreClientError]
 
 
-class PersonalizeRuntimeClient:
+class PersonalizeRuntimeClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        PersonalizeRuntimeClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#can_paginate)
         """
 
@@ -62,7 +67,7 @@ class PersonalizeRuntimeClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#generate_presigned_url)
         """
 
@@ -79,7 +84,7 @@ class PersonalizeRuntimeClient:
         """
         Re-ranks a list of recommended items for the given user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#get_personalized_ranking)
         """
 
@@ -97,6 +102,6 @@ class PersonalizeRuntimeClient:
         """
         Returns a list of recommended items.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#get_recommendations)
         """
